@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::Yancy;
-our $VERSION = '1.013';
+our $VERSION = '1.014';
 # ABSTRACT: Embed a simple admin CMS into your Mojolicious application
 
 #pod =head1 SYNOPSIS
@@ -308,8 +308,10 @@ our $VERSION = '1.013';
 #pod
 #pod     my $schema = $c->yancy->schema( $name );
 #pod     $c->yancy->schema( $name => $schema );
+#pod     my $schemas = $c->yancy->schema;
 #pod
-#pod Get or set the JSON schema for the given collection C<$name>.
+#pod Get or set the JSON schema for the given collection C<$name>. If no
+#pod collection name is given, returns a hashref of all the collections.
 #pod
 #pod =head2 yancy.openapi
 #pod
@@ -750,6 +752,9 @@ sub _helper_plugin {
 
 sub _helper_schema {
     my ( $c, $name, $schema ) = @_;
+    if ( !$name ) {
+        return $c->yancy->config->{collections};
+    }
     if ( $schema ) {
         $c->yancy->config->{collections}{ $name } = $schema;
         return;
@@ -885,7 +890,7 @@ Mojolicious::Plugin::Yancy - Embed a simple admin CMS into your Mojolicious appl
 
 =head1 VERSION
 
-version 1.013
+version 1.014
 
 =head1 SYNOPSIS
 
@@ -1193,8 +1198,10 @@ a collection name. Returns the hash of C<$filtered_data>.
 
     my $schema = $c->yancy->schema( $name );
     $c->yancy->schema( $name => $schema );
+    my $schemas = $c->yancy->schema;
 
-Get or set the JSON schema for the given collection C<$name>.
+Get or set the JSON schema for the given collection C<$name>. If no
+collection name is given, returns a hashref of all the collections.
 
 =head2 yancy.openapi
 
